@@ -1,4 +1,4 @@
-__version__ = "1.0.8"
+__version__ = "1.0.10"
 
 from .resolvers.default_resolver import DefaultResolver
 from .resolvers.resolver import Resolver
@@ -6,6 +6,7 @@ from .resolvers.scalar_resolvers.scalar_resolver import ScalarResolver
 from .resolvers.collection_resolvers.collection_resolver import CollectionResolver
 from .resolvers.post_processors.post_processor import PostProcessor
 
-from .functional.load import from_string, from_file_uri, from_cli, from_primitive
+from .functional.load import from_string, from_file_uri, from_cli
 from .functional.util import merge, mask_in, mask_out
-from .functional.dotlist import from_dotlist, to_dotlist
\ No newline at end of file
+from .functional.dotlist import from_dotlist, to_dotlist
+from .functional.convert import from_primitive, to_primitive
\ No newline at end of file
